Class AddPartnerRequest

All Implemented Interfaces:
SdkPojo, ToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest>

@Generated("software.amazon.awssdk:codegen") public final class AddPartnerRequest extends RedshiftRequest implements ToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest>
  • Method Details

    • accountId

      public final String accountId()

      The Amazon Web Services account ID that owns the cluster.

      Returns:
      The Amazon Web Services account ID that owns the cluster.
    • clusterIdentifier

      public final String clusterIdentifier()

      The cluster identifier of the cluster that receives data from the partner.

      Returns:
      The cluster identifier of the cluster that receives data from the partner.
    • databaseName

      public final String databaseName()

      The name of the database that receives data from the partner.

      Returns:
      The name of the database that receives data from the partner.
    • partnerName

      public final String partnerName()

      The name of the partner that is authorized to send data.

      Returns:
      The name of the partner that is authorized to send data.
    • toBuilder

      public AddPartnerRequest.Builder toBuilder()
      Specified by:
      toBuilder in interface ToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest>
      Specified by:
      toBuilder in class RedshiftRequest
    • builder

      public static AddPartnerRequest.Builder builder()
    • serializableBuilderClass

      public static Class<? extends AddPartnerRequest.Builder> serializableBuilderClass()
    • hashCode

      public final int hashCode()
      Overrides:
      hashCode in class AwsRequest
    • equals

      public final boolean equals(Object obj)
      Overrides:
      equals in class AwsRequest
    • equalsBySdkFields

      public final boolean equalsBySdkFields(Object obj)
      Specified by:
      equalsBySdkFields in interface SdkPojo
    • toString

      public final String toString()
      Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value.
      Overrides:
      toString in class Object
    • getValueForField

      public final <T> Optional<T> getValueForField(String fieldName, Class<T> clazz)
      Overrides:
      getValueForField in class SdkRequest
    • sdkFields

      public final List<SdkField<?>> sdkFields()
      Specified by:
      sdkFields in interface SdkPojo
    • sdkFieldNameToField

      public final Map<String,SdkField<?>> sdkFieldNameToField()
      Specified by:
      sdkFieldNameToField in interface SdkPojo