Class DescribeEventSubscriptionsRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<DescribeEventSubscriptionsRequest.Builder,DescribeEventSubscriptionsRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final booleanFor responses, this returns true if the service returned a value for the TagKeys property.final booleanFor responses, this returns true if the service returned a value for the TagValues property.final Stringmarker()An optional parameter that specifies the starting point to return a set of response records.final IntegerThe maximum number of response records to return in each call.static Class<? extends DescribeEventSubscriptionsRequest.Builder>final StringThe name of the Amazon Redshift event notification subscription to be described.tagKeys()A tag key or keys for which you want to return all matching event notification subscriptions that are associated with the specified key or keys.A tag value or values for which you want to return all matching event notification subscriptions that are associated with the specified tag value or values.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
subscriptionName
The name of the Amazon Redshift event notification subscription to be described.
- Returns:
- The name of the Amazon Redshift event notification subscription to be described.
-
maxRecords
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified
MaxRecordsvalue, a value is returned in amarkerfield of the response. You can retrieve the next set of records by retrying the command with the returned marker value.Default:
100Constraints: minimum 20, maximum 100.
- Returns:
- The maximum number of response records to return in each call. If the number of remaining response
records exceeds the specified
MaxRecordsvalue, a value is returned in amarkerfield of the response. You can retrieve the next set of records by retrying the command with the returned marker value.Default:
100Constraints: minimum 20, maximum 100.
-
marker
An optional parameter that specifies the starting point to return a set of response records. When the results of a DescribeEventSubscriptions request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in theMarkerfield of the response. You can retrieve the next set of response records by providing the returned marker value in theMarkerparameter and retrying the request.- Returns:
- An optional parameter that specifies the starting point to return a set of response records. When the
results of a DescribeEventSubscriptions request exceed the value specified in
MaxRecords, Amazon Web Services returns a value in theMarkerfield of the response. You can retrieve the next set of response records by providing the returned marker value in theMarkerparameter and retrying the request.
-
hasTagKeys
public final boolean hasTagKeys()For responses, this returns true if the service returned a value for the TagKeys property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tagKeys
A tag key or keys for which you want to return all matching event notification subscriptions that are associated with the specified key or keys. For example, suppose that you have subscriptions that are tagged with keys called
ownerandenvironment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag keys associated with them.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTagKeys()method.- Returns:
- A tag key or keys for which you want to return all matching event notification subscriptions that are
associated with the specified key or keys. For example, suppose that you have subscriptions that are
tagged with keys called
ownerandenvironment. If you specify both of these tag keys in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag keys associated with them.
-
hasTagValues
public final boolean hasTagValues()For responses, this returns true if the service returned a value for the TagValues property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
tagValues
A tag value or values for which you want to return all matching event notification subscriptions that are associated with the specified tag value or values. For example, suppose that you have subscriptions that are tagged with values called
adminandtest. If you specify both of these tag values in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag values associated with them.Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasTagValues()method.- Returns:
- A tag value or values for which you want to return all matching event notification subscriptions that are
associated with the specified tag value or values. For example, suppose that you have subscriptions that
are tagged with values called
adminandtest. If you specify both of these tag values in the request, Amazon Redshift returns a response with the subscriptions that have either or both of these tag values associated with them.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<DescribeEventSubscriptionsRequest.Builder,DescribeEventSubscriptionsRequest> - Specified by:
toBuilderin classRedshiftRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-