Class ModifyAuthenticationProfileResponse
java.lang.Object
software.amazon.awssdk.core.SdkResponse
software.amazon.awssdk.awscore.AwsResponse
software.amazon.awssdk.services.redshift.model.RedshiftResponse
software.amazon.awssdk.services.redshift.model.ModifyAuthenticationProfileResponse
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ModifyAuthenticationProfileResponse.Builder,ModifyAuthenticationProfileResponse>
@Generated("software.amazon.awssdk:codegen")
public final class ModifyAuthenticationProfileResponse
extends RedshiftResponse
implements ToCopyableBuilder<ModifyAuthenticationProfileResponse.Builder,ModifyAuthenticationProfileResponse>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe updated content of the authentication profile in JSON format.final StringThe name of the authentication profile that was replaced.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ModifyAuthenticationProfileResponse.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.services.redshift.model.RedshiftResponse
responseMetadataMethods inherited from class software.amazon.awssdk.core.SdkResponse
sdkHttpResponseMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
authenticationProfileName
The name of the authentication profile that was replaced.
- Returns:
- The name of the authentication profile that was replaced.
-
authenticationProfileContent
The updated content of the authentication profile in JSON format.
- Returns:
- The updated content of the authentication profile in JSON format.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ModifyAuthenticationProfileResponse.Builder,ModifyAuthenticationProfileResponse> - Specified by:
toBuilderin classAwsResponse
-
builder
-
serializableBuilderClass
public static Class<? extends ModifyAuthenticationProfileResponse.Builder> serializableBuilderClass() -
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsResponse
-
equals
- Overrides:
equalsin classAwsResponse
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkResponse
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-