Class ModifyEventSubscriptionRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ModifyEventSubscriptionRequest.Builder,ModifyEventSubscriptionRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionbuilder()final Booleanenabled()A Boolean value indicating if the subscription is enabled.final booleanfinal booleanequalsBySdkFields(Object obj) Specifies the Amazon Redshift event categories to be published by the event notification subscription.final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final booleanFor responses, this returns true if the service returned a value for the EventCategories property.final inthashCode()final booleanFor responses, this returns true if the service returned a value for the SourceIds property.static Class<? extends ModifyEventSubscriptionRequest.Builder>final Stringseverity()Specifies the Amazon Redshift event severity to be published by the event notification subscription.final StringThe Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription.A list of one or more identifiers of Amazon Redshift source objects.final StringThe type of source that will be generating the events.final StringThe name of the modified Amazon Redshift event notification subscription.final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
subscriptionName
The name of the modified Amazon Redshift event notification subscription.
- Returns:
- The name of the modified Amazon Redshift event notification subscription.
-
snsTopicArn
The Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription.
- Returns:
- The Amazon Resource Name (ARN) of the SNS topic to be used by the event notification subscription.
-
sourceType
The type of source that will be generating the events. For example, if you want to be notified of events generated by a cluster, you would set this parameter to cluster. If this value is not specified, events are returned for all Amazon Redshift objects in your Amazon Web Services account. You must specify a source type in order to specify source IDs.
Valid values: cluster, cluster-parameter-group, cluster-security-group, cluster-snapshot, and scheduled-action.
- Returns:
- The type of source that will be generating the events. For example, if you want to be notified of events
generated by a cluster, you would set this parameter to cluster. If this value is not specified, events
are returned for all Amazon Redshift objects in your Amazon Web Services account. You must specify a
source type in order to specify source IDs.
Valid values: cluster, cluster-parameter-group, cluster-security-group, cluster-snapshot, and scheduled-action.
-
hasSourceIds
public final boolean hasSourceIds()For responses, this returns true if the service returned a value for the SourceIds property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
sourceIds
A list of one or more identifiers of Amazon Redshift source objects. All of the objects must be of the same type as was specified in the source type parameter. The event subscription will return only events generated by the specified objects. If not specified, then events are returned for all objects within the source type specified.
Example: my-cluster-1, my-cluster-2
Example: my-snapshot-20131010
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasSourceIds()method.- Returns:
- A list of one or more identifiers of Amazon Redshift source objects. All of the objects must be of the
same type as was specified in the source type parameter. The event subscription will return only events
generated by the specified objects. If not specified, then events are returned for all objects within the
source type specified.
Example: my-cluster-1, my-cluster-2
Example: my-snapshot-20131010
-
hasEventCategories
public final boolean hasEventCategories()For responses, this returns true if the service returned a value for the EventCategories property. This DOES NOT check that the value is non-empty (for which, you should check theisEmpty()method on the property). This is useful because the SDK will never return a null collection or map, but you may need to differentiate between the service returning nothing (or null) and the service returning an empty collection or map. For requests, this returns true if a value for the property was specified in the request builder, and false if a value was not specified. -
eventCategories
Specifies the Amazon Redshift event categories to be published by the event notification subscription.
Values: configuration, management, monitoring, security, pending
Attempts to modify the collection returned by this method will result in an UnsupportedOperationException.
This method will never return null. If you would like to know whether the service returned this field (so that you can differentiate between null and empty), you can use the
hasEventCategories()method.- Returns:
- Specifies the Amazon Redshift event categories to be published by the event notification
subscription.
Values: configuration, management, monitoring, security, pending
-
severity
Specifies the Amazon Redshift event severity to be published by the event notification subscription.
Values: ERROR, INFO
- Returns:
- Specifies the Amazon Redshift event severity to be published by the event notification subscription.
Values: ERROR, INFO
-
enabled
A Boolean value indicating if the subscription is enabled.
trueindicates the subscription is enabled- Returns:
- A Boolean value indicating if the subscription is enabled.
trueindicates the subscription is enabled
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ModifyEventSubscriptionRequest.Builder,ModifyEventSubscriptionRequest> - Specified by:
toBuilderin classRedshiftRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-