Class ModifyUsageLimitRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<ModifyUsageLimitRequest.Builder,ModifyUsageLimitRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal Longamount()The new limit amount.final UsageLimitBreachActionThe new action that Amazon Redshift takes when the limit is reached.final StringThe new action that Amazon Redshift takes when the limit is reached.builder()final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()static Class<? extends ModifyUsageLimitRequest.Builder>final StringtoString()Returns a string representation of this object.final StringThe identifier of the usage limit to modify.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
usageLimitId
The identifier of the usage limit to modify.
- Returns:
- The identifier of the usage limit to modify.
-
amount
The new limit amount. For more information about this parameter, see UsageLimit.
- Returns:
- The new limit amount. For more information about this parameter, see UsageLimit.
-
breachAction
The new action that Amazon Redshift takes when the limit is reached. For more information about this parameter, see UsageLimit.
If the service returns an enum value that is not available in the current SDK version,
breachActionwill returnUsageLimitBreachAction.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frombreachActionAsString().- Returns:
- The new action that Amazon Redshift takes when the limit is reached. For more information about this parameter, see UsageLimit.
- See Also:
-
breachActionAsString
The new action that Amazon Redshift takes when the limit is reached. For more information about this parameter, see UsageLimit.
If the service returns an enum value that is not available in the current SDK version,
breachActionwill returnUsageLimitBreachAction.UNKNOWN_TO_SDK_VERSION. The raw value returned by the service is available frombreachActionAsString().- Returns:
- The new action that Amazon Redshift takes when the limit is reached. For more information about this parameter, see UsageLimit.
- See Also:
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<ModifyUsageLimitRequest.Builder,ModifyUsageLimitRequest> - Specified by:
toBuilderin classRedshiftRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-