Class AddPartnerRequest
java.lang.Object
software.amazon.awssdk.core.SdkRequest
software.amazon.awssdk.awscore.AwsRequest
software.amazon.awssdk.services.redshift.model.RedshiftRequest
software.amazon.awssdk.services.redshift.model.AddPartnerRequest
- All Implemented Interfaces:
SdkPojo,ToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest>
@Generated("software.amazon.awssdk:codegen")
public final class AddPartnerRequest
extends RedshiftRequest
implements ToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest>
-
Nested Class Summary
Nested Classes -
Method Summary
Modifier and TypeMethodDescriptionfinal StringThe Amazon Web Services account ID that owns the cluster.static AddPartnerRequest.Builderbuilder()final StringThe cluster identifier of the cluster that receives data from the partner.final StringThe name of the database that receives data from the partner.final booleanfinal booleanequalsBySdkFields(Object obj) final <T> Optional<T>getValueForField(String fieldName, Class<T> clazz) final inthashCode()final StringThe name of the partner that is authorized to send data.static Class<? extends AddPartnerRequest.Builder>final StringtoString()Returns a string representation of this object.Methods inherited from class software.amazon.awssdk.awscore.AwsRequest
overrideConfigurationMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface software.amazon.awssdk.utils.builder.ToCopyableBuilder
copy
-
Method Details
-
accountId
The Amazon Web Services account ID that owns the cluster.
- Returns:
- The Amazon Web Services account ID that owns the cluster.
-
clusterIdentifier
The cluster identifier of the cluster that receives data from the partner.
- Returns:
- The cluster identifier of the cluster that receives data from the partner.
-
databaseName
The name of the database that receives data from the partner.
- Returns:
- The name of the database that receives data from the partner.
-
partnerName
The name of the partner that is authorized to send data.
- Returns:
- The name of the partner that is authorized to send data.
-
toBuilder
- Specified by:
toBuilderin interfaceToCopyableBuilder<AddPartnerRequest.Builder,AddPartnerRequest> - Specified by:
toBuilderin classRedshiftRequest
-
builder
-
serializableBuilderClass
-
hashCode
public final int hashCode()- Overrides:
hashCodein classAwsRequest
-
equals
- Overrides:
equalsin classAwsRequest
-
equalsBySdkFields
- Specified by:
equalsBySdkFieldsin interfaceSdkPojo
-
toString
Returns a string representation of this object. This is useful for testing and debugging. Sensitive data will be redacted from this string using a placeholder value. -
getValueForField
- Overrides:
getValueForFieldin classSdkRequest
-
sdkFields
-
sdkFieldNameToField
- Specified by:
sdkFieldNameToFieldin interfaceSdkPojo
-